==> prestashop_1.5.0.13.zip: prestashop/modules/carriercompare/translations/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{carriercompare}prestashop>carriercompare_115484428c82f859100c07ae1170d9e0'] = 'Estimación de la entrega';
$_MODULE['<{carriercompare}prestashop>carriercompare_68e114c207a6820a8f14d0eceacf17d7'] = 'Módulo que permite hacer una estimación de los gastos de envío antes de comenzar el proceso de compra.';
$_MODULE['<{carriercompare}prestashop>carriercompare_ed70a57a190d596171cf324c16a2277d'] = 'El identificante State no es válido';
$_MODULE['<{carriercompare}prestashop>carriercompare_ff22c3e7b4cd12813e2033774d987e96'] = 'Por favor seleccione un estado';
$_MODULE['<{carriercompare}prestashop>carriercompare_fb9e838d470b2c27c2c128d127165f9e'] = 'Por favor seleccione un Pais';
$_MODULE['<{carriercompare}prestashop>carriercompare_b72dd62d03697b37417288c63e78c8c6'] = 'Por favor, utilice un código postal válido en función del país elegido';
$_MODULE['<{carriercompare}prestashop>carriercompare_3f63451bbacbb1c3303d99d0309fdfe9'] = 'Por favor seleccione un transportista';
$_MODULE['<{carriercompare}prestashop>carriercompare_efaf5c3827ef576b05de32ad458f196c'] = 'Este identificante de transportista no se encuentra disponible para esta selección';
$_MODULE['<{carriercompare}prestashop>carriercompare_a0593567d9366b570d33cd3ac81042df'] = 'Imposible actualizar el carrito';
$_MODULE['<{carriercompare}prestashop>carriercompare_e7a6ca4e744870d455a57b644f696457'] = '¡Gratis!';
$_MODULE['<{carriercompare}prestashop>carriercompare_fbc1bef527a3a092053a244fd8d87abf'] = 'Haga una estimación de sus gastos de envío e impuestos';
$_MODULE['<{carriercompare}prestashop>carriercompare_59716c97497eb9694541f7c3d37b1a4d'] = 'País';
$_MODULE['<{carriercompare}prestashop>carriercompare_46a2a41cc6e552044816a2d04634545d'] = 'Estados';
$_MODULE['<{carriercompare}prestashop>carriercompare_e0ed8e71dbd22a1e91cb570b52443fd5'] = 'Código postal';
$_MODULE['<{carriercompare}prestashop>carriercompare_51e304bfd2872c9f53c99054b8fb8381'] = 'Necesario para algunos transportistas';
$_MODULE['<{carriercompare}prestashop>carriercompare_914419aa32f04011357d3b604a86d7eb'] = 'Transportista';
$_MODULE['<{carriercompare}prestashop>carriercompare_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Información';
$_MODULE['<{carriercompare}prestashop>carriercompare_3601146c4e948c32b6424d2c0a7f0118'] = 'Precio';
$_MODULE['<{carriercompare}prestashop>carriercompare_f620c0ed0c89129c9dd8953406300061'] = 'Ninguna compañía está disponible para esta selección';
$_MODULE['<{carriercompare}prestashop>carriercompare_63a6a88c066880c5ac42394a22803ca6'] = 'refrescar';
$_MODULE['<{carriercompare}prestashop>carriercompare_36126598ecb1141cd37a92f48e7727f1'] = 'Refrescando y la actualización la cesta ...';
$_MODULE['<{carriercompare}prestashop>carriercompare_43b6864a312731efd637b6f15716656f'] = 'Comprobación de los estados disponibles ...';
$_MODULE['<{carriercompare}prestashop>carriercompare_c38be8e252777b47067cfe4de79b80a3'] = 'Recuperación de la información ...';
$_MODULE['<{carriercompare}prestashop>carriercompare_8a1ac57c0cc4eb3f6b2fe4c252518c37'] = 'Actualización de la compra';
$_MODULE['<{carriercompare}prestashop>carriercompare_653e78154f5596fc293bf9db65110bbd'] = 'Actualizar lista de proveedores';
$_MODULE['<{carriercompare}prestashop>configuration_aa4c031e8f3c596aaac3ba13f5f91c75'] = 'Ha ocurrido un error durante la validación de formularios';
$_MODULE['<{carriercompare}prestashop>configuration_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuración actualizada';
$_MODULE['<{carriercompare}prestashop>configuration_6408d076fa6417e7bc8ddc3cdf9a0644'] = 'Configuración global';
$_MODULE['<{carriercompare}prestashop>configuration_4c1f76824b0d7333652d5f64a3e07ef5'] = 'En cualquier momento';
$_MODULE['<{carriercompare}prestashop>configuration_d82928a663ff868502586a0c515e602b'] = 'Se requiere todo el conjunto de información';
$_MODULE['<{carriercompare}prestashop>configuration_7a23a5abbb503885bf1d6186033eca81'] = 'Establecer el modo para volver a cargar la información de un cliente';
$_MODULE['<{carriercompare}prestashop>configuration_a4d3b161ce1309df1c4e25df28694b7b'] = 'Enviar';

==> prestashop_1.5.0.17.zip: prestashop/modules/carriercompare/translations/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{carriercompare}prestashop>carriercompare_115484428c82f859100c07ae1170d9e0'] = 'Estimación de la entrega';
$_MODULE['<{carriercompare}prestashop>carriercompare_68e114c207a6820a8f14d0eceacf17d7'] = 'Módulo que permite hacer una estimación de los gastos de envío antes de comenzar el proceso de compra.';
$_MODULE['<{carriercompare}prestashop>carriercompare_ed70a57a190d596171cf324c16a2277d'] = 'El identificante State no es válido';
$_MODULE['<{carriercompare}prestashop>carriercompare_ff22c3e7b4cd12813e2033774d987e96'] = 'Por favor seleccione un estado';
$_MODULE['<{carriercompare}prestashop>carriercompare_fb9e838d470b2c27c2c128d127165f9e'] = 'Por favor seleccione un Pais';
$_MODULE['<{carriercompare}prestashop>carriercompare_b72dd62d03697b37417288c63e78c8c6'] = 'Por favor, utilice un código postal válido en función del país elegido';
$_MODULE['<{carriercompare}prestashop>carriercompare_3f63451bbacbb1c3303d99d0309fdfe9'] = 'Por favor seleccione un transportista';
$_MODULE['<{carriercompare}prestashop>carriercompare_efaf5c3827ef576b05de32ad458f196c'] = 'Este identificante de transportista no se encuentra disponible para esta selección';
$_MODULE['<{carriercompare}prestashop>carriercompare_a0593567d9366b570d33cd3ac81042df'] = 'Imposible actualizar el carrito';
$_MODULE['<{carriercompare}prestashop>carriercompare_e7a6ca4e744870d455a57b644f696457'] = '¡Gratis!';
$_MODULE['<{carriercompare}prestashop>carriercompare_fbc1bef527a3a092053a244fd8d87abf'] = 'Haga una estimación de sus gastos de envío e impuestos';
$_MODULE['<{carriercompare}prestashop>carriercompare_59716c97497eb9694541f7c3d37b1a4d'] = 'País';
$_MODULE['<{carriercompare}prestashop>carriercompare_46a2a41cc6e552044816a2d04634545d'] = 'Estados';
$_MODULE['<{carriercompare}prestashop>carriercompare_e0ed8e71dbd22a1e91cb570b52443fd5'] = 'Código postal';
$_MODULE['<{carriercompare}prestashop>carriercompare_51e304bfd2872c9f53c99054b8fb8381'] = 'Necesario para algunos transportistas';
$_MODULE['<{carriercompare}prestashop>carriercompare_914419aa32f04011357d3b604a86d7eb'] = 'Transportista';
$_MODULE['<{carriercompare}prestashop>carriercompare_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Información';
$_MODULE['<{carriercompare}prestashop>carriercompare_3601146c4e948c32b6424d2c0a7f0118'] = 'Precio';
$_MODULE['<{carriercompare}prestashop>carriercompare_f620c0ed0c89129c9dd8953406300061'] = 'Ninguna compañía está disponible para esta selección';
$_MODULE['<{carriercompare}prestashop>carriercompare_63a6a88c066880c5ac42394a22803ca6'] = 'refrescar';
$_MODULE['<{carriercompare}prestashop>carriercompare_36126598ecb1141cd37a92f48e7727f1'] = 'Refrescando y la actualización la cesta ...';
$_MODULE['<{carriercompare}prestashop>carriercompare_43b6864a312731efd637b6f15716656f'] = 'Comprobación de los estados disponibles ...';
$_MODULE['<{carriercompare}prestashop>carriercompare_c38be8e252777b47067cfe4de79b80a3'] = 'Recuperación de la información ...';
$_MODULE['<{carriercompare}prestashop>carriercompare_8a1ac57c0cc4eb3f6b2fe4c252518c37'] = 'Actualización de la compra';
$_MODULE['<{carriercompare}prestashop>carriercompare_653e78154f5596fc293bf9db65110bbd'] = 'Actualizar lista de proveedores';
$_MODULE['<{carriercompare}prestashop>configuration_aa4c031e8f3c596aaac3ba13f5f91c75'] = 'Ha ocurrido un error durante la validación de formularios';
$_MODULE['<{carriercompare}prestashop>configuration_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuración actualizada';
$_MODULE['<{carriercompare}prestashop>configuration_963744bc6b0cce93e202d860a4a2f84a'] = 'Este modulo es disponible sólo en un proceso básico de pedido porque en la \"One Page Checkout\" la lista ya esta disponible';
$_MODULE['<{carriercompare}prestashop>configuration_6408d076fa6417e7bc8ddc3cdf9a0644'] = 'Configuración global';
$_MODULE['<{carriercompare}prestashop>configuration_4c1f76824b0d7333652d5f64a3e07ef5'] = 'En cualquier momento';
$_MODULE['<{carriercompare}prestashop>configuration_d82928a663ff868502586a0c515e602b'] = 'Se requiere todo el conjunto de información';
$_MODULE['<{carriercompare}prestashop>configuration_7a23a5abbb503885bf1d6186033eca81'] = 'Establecer el modo para volver a cargar la información de un cliente';
$_MODULE['<{carriercompare}prestashop>configuration_a4d3b161ce1309df1c4e25df28694b7b'] = 'Enviar';
